@@ -17,7 +17,7 @@ from pint import Quantity
 from typing import Optional
 
 from vivarium import divider_registry, serializer_registry, updater_registry
-from vivarium.core.process import Process, Step
+from vivarium.core.process import ParallelProcess, Process
 from vivarium.library.dict_utils import deep_merge, deep_merge_check, MULTI_UPDATE_KEY
 from vivarium.library.topology import without, dict_to_paths
 from vivarium.core.types import Processes, Topology, State, Steps, Flow
@@ -191,6 +191,12 @@ class Store:
       dictionary by default.
     * **_emit** (:py:class:`bool`): Whether to emit the variable to the
       :term:`emitter`. This is ``False`` by default.
+    * **_serializer** (:py:class:`vivarium.core.registry.Serializer` or
+      :py:class:`str`): Serializer (or name of serializer) whose ``serialize``
+      method should be called on data in this store before emitting and whose
+      ``deserialize`` method should be called when repopulating this store
+      from serialized data. Only define if it is necessary to serialize and
+      deserialize data in this store differently from other data of the same type.
     """
     schema_keys = {
         '_default',
@@ -651,9 +657,6 @@ class Store:
                     self.units = self.units or self.default[0].units
                     self.serializer = (self.serializer or
                                        serializer_registry.access('units'))
-                elif isinstance(self.default, np.ndarray):
-                    self.serializer = (self.serializer or
-                                       serializer_registry.access('numpy'))
 
             if '_value' in config:
                 self.value = self._check_schema(
@@ -1021,13 +1024,11 @@ class Store:
         if self.emit:
             if self.serializer:
                 if isinstance(self.value, list) and self.units:
-                    return self.serializer.serialize(
-                        [v.to(self.units) for v in self.value])
+                    return [self.serializer.serialize(v.to(self.units))
+                            for v in self.value]
                 if self.units:
                     return self.serializer.serialize(
                         self.value.to(self.units))
-                if isinstance(self.value, list):
-                    return self.value
                 return self.serializer.serialize(self.value)
             if self.units:
                 return self.value.to(self.units).magnitude
@@ -1056,6 +1057,15 @@ class Store:
         else:
             self.emit = emit
 
+    def recursive_end_process(self, value):
+        if isinstance(value.value, ParallelProcess):
+            value.value.end()
+            return
+        elif isinstance(value, Store):
+            for subval in value.inner:
+                self.recursive_end_process(value[subval])
+        return
+    
     def _delete_path(self, path):
         """
         Delete the subtree at the given path.
@@ -1069,6 +1079,8 @@ class Store:
         remove = path[-1]
         if remove in target.inner:
             lost = target.inner[remove]
+            # End any parallel processes to be deleted
+            self.recursive_end_process(target.inner[remove])
             del target.inner[remove]
             return lost
         return None
